﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;
using Infragistics.Win.UltraWinGrid;

namespace Dependent_DropDowns_CS
{
    public partial class Form1 : Form
    {
        #region Constructor
        public Form1()
        {
            InitializeComponent();
        }
        #endregion //Constructor

        #region Private Members
        private DataSet ds;
        UltraDropDown statesDropDown;
        UltraDropDown citiesDropDown;
        UltraComboEditor statesDropDown1;
        UltraComboEditor citiesDropDown1;
        #endregion // Private Members

        #region Event Handlers

        #region Form1_Load
        private void Form1_Load(object sender, EventArgs e)
        {
            this.BuildData();
            this.ultraGrid1.SetDataBinding(this.ds, "Customers");
            statesDropDown1.CheckedListSettings.CheckBoxStyle = CheckStyle.CheckBox;
            citiesDropDown1.CheckedListSettings.CheckBoxStyle = CheckStyle.CheckBox;
        }
        #endregion // Form1_Load

        #region ultraGrid1_InitializeLayout
        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            // Allow adding new rows. 
            //
            e.Layout.Override.AllowAddNew = AllowAddNew.TemplateOnBottom;

            // Create an UltraDropDown with a list of States for the State column. 
            //
            this.statesDropDown1 = new UltraComboEditor();
            this.Controls.Add(statesDropDown1);
            statesDropDown1.SetDataBinding(this.ds, "States");
            statesDropDown1.ValueMember = "ID";
            statesDropDown1.DisplayMember = "State";

            // Create an UltraDropDown with a list of cities for the City column. 
            // This dropdown will contain a complete list of all cities in all states
            // and we will filter it based on the current row so that only cities for the 
            // selected state are displayed. 
            //
            this.citiesDropDown1 = new UltraComboEditor();
            this.Controls.Add(citiesDropDown1);
            citiesDropDown1.SetDataBinding(this.ds, "Cities");
            citiesDropDown1.ValueMember = "ID";
            citiesDropDown1.DisplayMember = "City";            

            // Attach the dropdowns to the grid columns. 
            //
            e.Layout.Bands[0].Columns["State"].EditorComponent = statesDropDown1;
            e.Layout.Bands[0].Columns["City"].EditorComponent = citiesDropDown1;
        }
        #endregion // ultraGrid1_InitializeLayout

        #region ultraGrid1_BeforeCellActivate
        private void ultraGrid1_BeforeCellActivate(object sender, CancelableCellEventArgs e)
        {
            if (e.Cell.Column.Key == "City")
            {
                this.ds.Tables[2].DefaultView.RowFilter = "StateID = '"+ e.Cell.Row.Cells["State"].Value + "'";


                citiesDropDown1.DataSource = this.ds.Tables[2].DefaultView;

                // Before a cell in the City column is activated, change the filter on the 
                // DropDown to only display cities in the selected State. 
                //UltraGridBand rootBand = this.citiesDropDown.DisplayLayout.Bands[0];
                //rootBand.ColumnFilters.ClearAllFilters();
                //rootBand.ColumnFilters["StateID"].FilterConditions.Add(FilterComparisionOperator.Equals, e.Cell.Row.Cells["State"].Value);

                //UltraGridBand rootBand = this.citiesDropDown.DisplayLayout.Bands[0];
                //rootBand.ColumnFilters.ClearAllFilters();
                //rootBand.ColumnFilters["StateID"].FilterConditions.Add(FilterComparisionOperator.Equals, e.Cell.Row.Cells["State"].Value);
            }
        }
        #endregion // ultraGrid1_BeforeCellActivate

        #region ultraGrid1_AfterCellUpdate
        private void ultraGrid1_AfterCellUpdate(object sender, CellEventArgs e)
        {
            UltraGrid grid = (UltraGrid)sender;

            // Turn off the event to prevent recursion
            grid.EventManager.SetEnabled(GridEventIds.AfterCellUpdate, false);


            try
            {
                if (e.Cell.Column.Key == "State")
                {
                    // If the State is changed, the city is no longer valid, so clear it out.                     
                    e.Cell.Row.Cells["City"].Value = DBNull.Value;
                }
            }
            finally
            {
                // Re-enabled this event. 
                grid.EventManager.SetEnabled(GridEventIds.AfterCellUpdate, true);
            }
        }
        #endregion // ultraGrid1_AfterCellUpdate
        
        #endregion // Event Handlers

        #region Data

        // Build a list of states and cities. 
        private void BuildData()
        {
            this.ds = new DataSet();
            DataTable customersTable = this.ds.Tables.Add("Customers");
            customersTable.Columns.Add("Name", typeof(String));
            customersTable.Columns.Add("State", typeof(String));
            customersTable.Columns.Add("City", typeof(int));

            DataTable statesTable = this.ds.Tables.Add("States");
            statesTable.Columns.Add("ID", typeof(String));
            statesTable.Columns.Add("State", typeof(String));

            DataTable citiesTable = this.ds.Tables.Add("Cities");
            DataColumn cityIdColumn = citiesTable.Columns.Add("ID", typeof(int));
            cityIdColumn.AutoIncrement = true;
            citiesTable.Columns.Add("StateID", typeof(String));
            citiesTable.Columns.Add("City", typeof(String));

            statesTable.Rows.Add(new object[] { "AL", "Alabama" });
            citiesTable.Rows.Add(new object[] { null, "AL", "Birmingham" });
            citiesTable.Rows.Add(new object[] { null, "AL", "Montgomery" });
            citiesTable.Rows.Add(new object[] { null, "AL", "Mobile" });

            statesTable.Rows.Add(new object[] { "AK", "Alaska" });
            citiesTable.Rows.Add(new object[] { null, "AK", "Anchorage" });
            citiesTable.Rows.Add(new object[] { null, "AK", "Fairbanks" });
            citiesTable.Rows.Add(new object[] { null, "AK", "Juneau" });

            statesTable.Rows.Add(new object[] { "AZ", "Arizona" });
            citiesTable.Rows.Add(new object[] { null, "AZ", "Phoenix" });
            citiesTable.Rows.Add(new object[] { null, "AZ", "Tucson" });
            citiesTable.Rows.Add(new object[] { null, "AZ", "Mesa" });

            statesTable.Rows.Add(new object[] { "AR", "Arkansas" });
            citiesTable.Rows.Add(new object[] { null, "AR", "Little Rock" });
            citiesTable.Rows.Add(new object[] { null, "AR", "Fort Smith" });
            citiesTable.Rows.Add(new object[] { null, "AR", "North Little Rock" });

            statesTable.Rows.Add(new object[] { "CA", "California" });
            citiesTable.Rows.Add(new object[] { null, "CA", "Los Angeles" });
            citiesTable.Rows.Add(new object[] { null, "CA", "San Diego" });
            citiesTable.Rows.Add(new object[] { null, "CA", "San Jose" });

            statesTable.Rows.Add(new object[] { "CO", "Colorado" });
            citiesTable.Rows.Add(new object[] { null, "CO", "Denver" });
            citiesTable.Rows.Add(new object[] { null, "CO", "Colorodo Springs" });
            citiesTable.Rows.Add(new object[] { null, "CO", "Aurora" });

            statesTable.Rows.Add(new object[] { "CT", "Connecticut" });
            citiesTable.Rows.Add(new object[] { null, "CT", "Bridgeport" });
            citiesTable.Rows.Add(new object[] { null, "CT", "New Haven" });
            citiesTable.Rows.Add(new object[] { null, "CT", "Hartford" });

            statesTable.Rows.Add(new object[] { "DE", "Delaware" });
            citiesTable.Rows.Add(new object[] { null, "DE", "Wilmington" });
            citiesTable.Rows.Add(new object[] { null, "DE", "Dover" });
            citiesTable.Rows.Add(new object[] { null, "DE", "Newark" });

            statesTable.Rows.Add(new object[] { "FL", "Florida" });
            citiesTable.Rows.Add(new object[] { null, "FL", "Jacksonville" });
            citiesTable.Rows.Add(new object[] { null, "FL", "Miami" });
            citiesTable.Rows.Add(new object[] { null, "FL", "Tampa" });

            statesTable.Rows.Add(new object[] { "GA", "Georgia" });
            citiesTable.Rows.Add(new object[] { null, "GA", "Atlanta" });
            citiesTable.Rows.Add(new object[] { null, "GA", "Augusta-Richmond" });
            citiesTable.Rows.Add(new object[] { null, "GA", "Columbus" });

            statesTable.Rows.Add(new object[] { "HI", "Hawaii" });
            citiesTable.Rows.Add(new object[] { null, "HI", "Honolulu" });
            citiesTable.Rows.Add(new object[] { null, "HI", "Hilo" });
            citiesTable.Rows.Add(new object[] { null, "HI", "Kailua" });

            statesTable.Rows.Add(new object[] { "ID", "Idaho" });
            citiesTable.Rows.Add(new object[] { null, "ID", "Boise City" });
            citiesTable.Rows.Add(new object[] { null, "ID", "Nampa" });
            citiesTable.Rows.Add(new object[] { null, "ID", "Pocatello" });

            statesTable.Rows.Add(new object[] { "IL", "Illinois" });
            citiesTable.Rows.Add(new object[] { null, "IL", "Chicago" });
            citiesTable.Rows.Add(new object[] { null, "IL", "Rockford" });
            citiesTable.Rows.Add(new object[] { null, "IL", "Aurora" });

            statesTable.Rows.Add(new object[] { "IN", "Indiana" });
            citiesTable.Rows.Add(new object[] { null, "IN", "Indianapolis" });
            citiesTable.Rows.Add(new object[] { null, "IN", "Fort Wayne" });
            citiesTable.Rows.Add(new object[] { null, "IN", "Evansville" });

            statesTable.Rows.Add(new object[] { "IA", "Iowa" });
            citiesTable.Rows.Add(new object[] { null, "IA", "Des Moines" });
            citiesTable.Rows.Add(new object[] { null, "IA", "Cedar Rapids" });
            citiesTable.Rows.Add(new object[] { null, "IA", "Davenport" });

            statesTable.Rows.Add(new object[] { "KS", "Kansas" });
            citiesTable.Rows.Add(new object[] { null, "KS", "Wichita" });
            citiesTable.Rows.Add(new object[] { null, "KS", "Overland Park" });
            citiesTable.Rows.Add(new object[] { null, "KS", "Kansas City" });

            statesTable.Rows.Add(new object[] { "KY", "Kentucky" });
            citiesTable.Rows.Add(new object[] { null, "KY", "Lexington-Fayette" });
            citiesTable.Rows.Add(new object[] { null, "KY", "Louisville" });
            citiesTable.Rows.Add(new object[] { null, "KY", "Owensboro" });

            statesTable.Rows.Add(new object[] { "LA", "Louisiana" });
            citiesTable.Rows.Add(new object[] { null, "LA", "New Orleans" });
            citiesTable.Rows.Add(new object[] { null, "LA", "Baton Rouge" });
            citiesTable.Rows.Add(new object[] { null, "LA", "Shreveport" });

            statesTable.Rows.Add(new object[] { "ME", "Maine" });
            citiesTable.Rows.Add(new object[] { null, "ME", "Portland" });
            citiesTable.Rows.Add(new object[] { null, "ME", "Lewiston" });
            citiesTable.Rows.Add(new object[] { null, "ME", "Bangor" });

            statesTable.Rows.Add(new object[] { "MD", "Maryland" });
            citiesTable.Rows.Add(new object[] { null, "MD", "Baltimore" });
            citiesTable.Rows.Add(new object[] { null, "MD", "Columbia" });
            citiesTable.Rows.Add(new object[] { null, "MD", "Silver Spring" });

            statesTable.Rows.Add(new object[] { "MA", "Massachusetts" });
            citiesTable.Rows.Add(new object[] { null, "MA", "Boston" });
            citiesTable.Rows.Add(new object[] { null, "MA", "Worcester" });
            citiesTable.Rows.Add(new object[] { null, "MA", "Springfield" });

            statesTable.Rows.Add(new object[] { "MI", "Michigan" });
            citiesTable.Rows.Add(new object[] { null, "MI", "Detroit" });
            citiesTable.Rows.Add(new object[] { null, "MI", "Grand Rapids" });
            citiesTable.Rows.Add(new object[] { null, "MI", "Warren" });

            statesTable.Rows.Add(new object[] { "MN", "Minnesota" });
            citiesTable.Rows.Add(new object[] { null, "MN", "Minneapolis" });
            citiesTable.Rows.Add(new object[] { null, "MN", "St. Paul" });
            citiesTable.Rows.Add(new object[] { null, "MN", "Deluth" });

            statesTable.Rows.Add(new object[] { "MS", "Mississippi" });
            citiesTable.Rows.Add(new object[] { null, "MS", "Jackson" });
            citiesTable.Rows.Add(new object[] { null, "MS", "Gulfport" });
            citiesTable.Rows.Add(new object[] { null, "MS", "Biloxi" });

            statesTable.Rows.Add(new object[] { "MO", "Missouri" });
            citiesTable.Rows.Add(new object[] { null, "MO", "Kansas City" });
            citiesTable.Rows.Add(new object[] { null, "MO", "St. Louis" });
            citiesTable.Rows.Add(new object[] { null, "MO", "Springfield" });

            statesTable.Rows.Add(new object[] { "MT", "Montana" });
            citiesTable.Rows.Add(new object[] { null, "MT", "Billings" });
            citiesTable.Rows.Add(new object[] { null, "MT", "Missoula" });
            citiesTable.Rows.Add(new object[] { null, "MT", "Great Falls" });

            statesTable.Rows.Add(new object[] { "NE", "Nebraska" });
            citiesTable.Rows.Add(new object[] { null, "NE", "Omaha" });
            citiesTable.Rows.Add(new object[] { null, "NE", "Lincoln" });
            citiesTable.Rows.Add(new object[] { null, "NE", "Bellevue" });

            statesTable.Rows.Add(new object[] { "NV", "Nevada" });
            citiesTable.Rows.Add(new object[] { null, "NV", "Las Vegas" });
            citiesTable.Rows.Add(new object[] { null, "NV", "Paradise" });
            citiesTable.Rows.Add(new object[] { null, "NV", "Reno" });

            statesTable.Rows.Add(new object[] { "NH", "New Hampshire" });
            citiesTable.Rows.Add(new object[] { null, "NH", "Manchester" });
            citiesTable.Rows.Add(new object[] { null, "NH", "Nashua" });
            citiesTable.Rows.Add(new object[] { null, "NH", "Concord" });

            statesTable.Rows.Add(new object[] { "NJ", "New Jersey" });
            citiesTable.Rows.Add(new object[] { null, "NJ", "Newark" });
            citiesTable.Rows.Add(new object[] { null, "NJ", "Jeresy City" });
            citiesTable.Rows.Add(new object[] { null, "NJ", "Paterson" });

            statesTable.Rows.Add(new object[] { "NM", "New Mexico" });
            citiesTable.Rows.Add(new object[] { null, "NM", "Albuquerque" });
            citiesTable.Rows.Add(new object[] { null, "NM", "Las Cruces" });
            citiesTable.Rows.Add(new object[] { null, "NM", "Santa Fe" });

            statesTable.Rows.Add(new object[] { "NY", "New York" });
            citiesTable.Rows.Add(new object[] { null, "NY", "New York" });
            citiesTable.Rows.Add(new object[] { null, "NY", "Buffalo" });
            citiesTable.Rows.Add(new object[] { null, "NY", "Rochester" });

            statesTable.Rows.Add(new object[] { "NC", "North Carolina" });
            citiesTable.Rows.Add(new object[] { null, "NC", "Charlotte" });
            citiesTable.Rows.Add(new object[] { null, "NC", "Raleigh" });
            citiesTable.Rows.Add(new object[] { null, "NC", "Greensboro" });

            statesTable.Rows.Add(new object[] { "ND", "North Dakota" });
            citiesTable.Rows.Add(new object[] { null, "ND", "Fargo" });
            citiesTable.Rows.Add(new object[] { null, "ND", "Bismark" });
            citiesTable.Rows.Add(new object[] { null, "ND", "Grand Forks" });

            statesTable.Rows.Add(new object[] { "OH", "Ohio" });
            citiesTable.Rows.Add(new object[] { null, "OH", "Columbus" });
            citiesTable.Rows.Add(new object[] { null, "OH", "Cleveland" });
            citiesTable.Rows.Add(new object[] { null, "OH", "Cincinnati" });

            statesTable.Rows.Add(new object[] { "OK", "Oklahoma" });
            citiesTable.Rows.Add(new object[] { null, "OK", "Oklahoma City" });
            citiesTable.Rows.Add(new object[] { null, "OK", "Tulsa" });
            citiesTable.Rows.Add(new object[] { null, "OK", "Norman" });

            statesTable.Rows.Add(new object[] { "OR", "Oregon" });
            citiesTable.Rows.Add(new object[] { null, "OR", "Portland" });
            citiesTable.Rows.Add(new object[] { null, "OR", "Eugene" });
            citiesTable.Rows.Add(new object[] { null, "OR", "Salem" });

            statesTable.Rows.Add(new object[] { "PA", "Pennsylvania" });
            citiesTable.Rows.Add(new object[] { null, "PA", "Philadelphia" });
            citiesTable.Rows.Add(new object[] { null, "PA", "Pittsburgh" });
            citiesTable.Rows.Add(new object[] { null, "PA", "Allentown" });

            statesTable.Rows.Add(new object[] { "RI", "Rhode Island" });
            citiesTable.Rows.Add(new object[] { null, "RI", "Providence" });
            citiesTable.Rows.Add(new object[] { null, "RI", "Warwick" });
            citiesTable.Rows.Add(new object[] { null, "RI", "Cranston" });

            statesTable.Rows.Add(new object[] { "SC", "South Carolina" });
            citiesTable.Rows.Add(new object[] { null, "SC", "Columbia" });
            citiesTable.Rows.Add(new object[] { null, "SC", "Charleston" });
            citiesTable.Rows.Add(new object[] { null, "SC", "North Charleston" });

            statesTable.Rows.Add(new object[] { "SD", "South Dakota" });
            citiesTable.Rows.Add(new object[] { null, "SD", "Sioux Falls" });
            citiesTable.Rows.Add(new object[] { null, "SD", "Rapid City" });
            citiesTable.Rows.Add(new object[] { null, "SD", "Aberdeen" });

            statesTable.Rows.Add(new object[] { "TN", "Tennessee" });
            citiesTable.Rows.Add(new object[] { null, "TN", "Memphis" });
            citiesTable.Rows.Add(new object[] { null, "TN", "Nashville-Davidson" });
            citiesTable.Rows.Add(new object[] { null, "TN", "Knoxville" });

            statesTable.Rows.Add(new object[] { "TX", "Texas" });
            citiesTable.Rows.Add(new object[] { null, "TX", "Houston" });
            citiesTable.Rows.Add(new object[] { null, "TX", "Dallas" });
            citiesTable.Rows.Add(new object[] { null, "TX", "San Antonio" });

            statesTable.Rows.Add(new object[] { "UT", "Utah" });
            citiesTable.Rows.Add(new object[] { null, "UT", "Salt Lake City" });
            citiesTable.Rows.Add(new object[] { null, "UT", "West Valley City" });
            citiesTable.Rows.Add(new object[] { null, "UT", "Provo" });

            statesTable.Rows.Add(new object[] { "VT", "Vermont" });
            citiesTable.Rows.Add(new object[] { null, "VT", "Burlington" });
            citiesTable.Rows.Add(new object[] { null, "VT", "Rutland" });
            citiesTable.Rows.Add(new object[] { null, "VT", "South Burlington" });

            statesTable.Rows.Add(new object[] { "VA", "Virginia" });
            citiesTable.Rows.Add(new object[] { null, "VA", "Virginia Beach" });
            citiesTable.Rows.Add(new object[] { null, "VA", "Norfolk" });
            citiesTable.Rows.Add(new object[] { null, "VA", "Chesapeake" });

            statesTable.Rows.Add(new object[] { "WA", "Washington" });
            citiesTable.Rows.Add(new object[] { null, "WA", "Seattle" });
            citiesTable.Rows.Add(new object[] { null, "WA", "Spokane" });
            citiesTable.Rows.Add(new object[] { null, "WA", "Tacoma" });

            statesTable.Rows.Add(new object[] { "WV", "West Virginia" });
            citiesTable.Rows.Add(new object[] { null, "WV", "Charleston" });
            citiesTable.Rows.Add(new object[] { null, "WV", "Huntington" });
            citiesTable.Rows.Add(new object[] { null, "WV", "Parkersburg" });

            statesTable.Rows.Add(new object[] { "WI", "Wisconsin" });
            citiesTable.Rows.Add(new object[] { null, "WI", "Milwaukee" });
            citiesTable.Rows.Add(new object[] { null, "WI", "Madison" });
            citiesTable.Rows.Add(new object[] { null, "WI", "Green Bay" });

            statesTable.Rows.Add(new object[] { "WY", "Wyoming" });
            citiesTable.Rows.Add(new object[] { null, "WY", "Cheyeen" });
            citiesTable.Rows.Add(new object[] { null, "WY", "Caspar" });
            citiesTable.Rows.Add(new object[] { null, "WY", "Laramie" });
        }

        #endregion //Data
    }
}
